# -*- coding: utf-8 -*-
from django.urls import reverse
from django.test import TestCase, Client

from django_presskit.models import Company, Project,\
    MonetizationPermission

class GeneralViewTests(TestCase):
    @classmethod
    def setUpTestData(cls):
        comp = Company.objects.create(title='Test Company',
            slug='test-company',
            description='Description',
            address='Place')
        perms = MonetizationPermission.objects.create(option='Test Permission')
        cls.project = Project.objects.create(title='Test Project',
            slug='test-project',
            press_can_request_copy=True,
            company=comp,
            monetization_permission=perms,
            website='example.com')
        cls.client = Client()

    def test_bad_company_redirects(self):
        response = self.client.get(reverse('django_presskit:company', kwargs={'company_slug': 'NotACompany'}))
        self.assertRedirects(response, reverse('django_presskit:default'))

    def test_bad_project_redirects(self):
        response = self.client.get(reverse('django_presskit:project', kwargs={'project_slug': 'NotAProject'}))
        self.assertRedirects(response, reverse('django_presskit:default'))

    def test_load_project(self):
        response = self.client.get(reverse('django_presskit:project',
                                           kwargs={'project_slug': self.project.slug}))
        self.assertContains(
            response, self.project.website, status_code=200)

    def test_load_project_xml(self):
        response = self.client.get(reverse('django_presskit:project_xml',
                                           kwargs={'project_slug': self.project.slug}))
        self.assertContains(
            response, self.project.website, count=1, status_code=200)

    def test_project_header_no_image_raises_404(self):
        response = self.client.get(reverse('django_presskit:project_header',
                                   kwargs={'project_slug': self.project.slug}))
        self.assertEquals(response.status_code, 404)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-02-02 20:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0003_auto_20181002_1915'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='additionallink',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='award',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='companyimageattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='companylogoattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='companyvideo',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='contact',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='credit',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='feature',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='platform',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='price',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='projectimageattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='projectlogoattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='quote',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='social',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='trailer',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AddField(
            model_name='additionallink',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='award',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='companyimageattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='companylogoattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='companyvideo',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='contact',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='credit',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='feature',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='platform',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='price',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='project',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='projectimageattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='projectlogoattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='quote',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='social',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='trailer',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2019-01-23 01:57
from __future__ import unicode_literals

from django.db import migrations
import django.db.models.deletion
import filer.fields.file


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0010_auto_20180414_2058'),
        ('django_presskit', '0003_auto_20181002_1915'),
    ]

    operations = [
        migrations.AddField(
            model_name='company',
            name='asset_archive',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='filer.File'),
        ),
        migrations.AddField(
            model_name='project',
            name='asset_archive',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='filer.File'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-02 18:47
from __future__ import unicode_literals

from django.db import migrations

def create_monetizations(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    MonetizationPermission = apps.get_model('django_presskit', 'MonetizationPermission')

    MonetizationPermission(option='False', description='The contents of this project are not allowed to be published through video broadcasting services.'
      ).save()
    MonetizationPermission(option='Ask', description='The contents of this project may be published through video broadcasting services with written permission.'
      ).save()
    MonetizationPermission(option='Non-Commercial', description='The contents of this project may be published through video broadcasting services for non-commercial purposes only. Monetization is not allowed without written permission.'
      ).save()
    MonetizationPermission(option='Monetize', description='The contents of this project may be published through video broadcasting services and these videos may be monetized.'
      ).save()

class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_monetizations),
    ]



from future import standard_library
standard_library.install_aliases()
import markdown
import re
from urllib.parse import urlparse
from django import template
from django.utils.html import conditional_escape
from django.utils.safestring import mark_safe

register = template.Library()

@register.filter('markdown')
def markdown_filter(text):
    return mark_safe(markdown.markdown(text))

@register.filter()
def with_protocol(value):
    if not value:
        return ''
    if re.match(r'^(?:http|\/\/)', value):
        return value
    return '//' + value

@register.inclusion_tag('django_presskit/navitem.html')
def optional_navitem(item, anchor, title):
    return {
        'item': item,
        'anchor': anchor,
        'title': title
    }

@register.filter()
def domain(value):
    if not value:
        return ''
    if re.match(r'^(?:http|\/\/)', value):
        return urlparse(value).netloc
    return urlparse('//' + value).netloc

@register.simple_tag(takes_context=True)
def absolute_url(context, viewname, *args, **kwargs):
    # Some code cribbed from Django's `url` tag.
    from django.urls import reverse, NoReverseMatch

    url = reverse(viewname, args=args, kwargs=kwargs)
    return context.request.build_absolute_uri(url)

@register.tag
def condense(parser, token):
    nodelist = parser.parse(('endcondense',))
    parser.delete_first_token()
    return CondenseNode(nodelist)

class CondenseNode(template.Node):
    def __init__(self, nodelist):
        self.nodelist = nodelist
    def render(self, context):
        output = self.nodelist.render(context)
        return re.sub(r'\s*\n+', '\n', output)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.contrib import admin
from adminsortable2.admin import SortableAdminMixin, SortableInlineAdminMixin

from .models import AdditionalLink, Attachment, Award, Company
from .models import CompanyImageAttachment, Contact, Credit, Feature
from .models import MonetizationPermission, Platform, Price, Project, Quote
from .models import Social, Trailer, CompanyVideo, ProjectImageAttachment
from .models import ProjectLogoAttachment, CompanyLogoAttachment

class CompanyImagesInline(SortableInlineAdminMixin, admin.StackedInline):
    model = CompanyImageAttachment
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class ProjectImagesInline(SortableInlineAdminMixin, admin.StackedInline):
    model = ProjectImageAttachment
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class ProjectLogosInline(SortableInlineAdminMixin, admin.StackedInline):
    model = ProjectLogoAttachment
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class CompanyLogosInline(SortableInlineAdminMixin, admin.StackedInline):
    model = CompanyLogoAttachment
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class SocialInline(SortableInlineAdminMixin, admin.TabularInline):
    model = Social
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class CompanyVideoInline(SortableInlineAdminMixin, admin.StackedInline):
    model = CompanyVideo
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class AdditionalLinkAdmin(SortableAdminMixin, admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)
    prepopulated_fields = {"slug": ("title",)}


class AttachmentAdmin(admin.ModelAdmin):
    pass


class AwardAdmin(SortableAdminMixin, admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)


class CompanyAdmin(admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)
    filter_horizontal = (
        'additional_links', 'quotes', 'contacts', 'credits', 'awards')
    inlines = [SocialInline, CompanyImagesInline, CompanyLogosInline, CompanyVideoInline]
    prepopulated_fields = {"slug": ("title",)}


class ContactAdmin(SortableAdminMixin, admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)


class CreditAdmin(SortableAdminMixin, admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)


class MonetizationPermissionAdmin(admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)


class FeatureInline(SortableInlineAdminMixin, admin.TabularInline):
    model = Feature
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class PlatformInline(SortableInlineAdminMixin, admin.TabularInline):
    model = Platform
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class PriceInline(SortableInlineAdminMixin, admin.TabularInline):
    model = Price
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class TrailerInline(SortableInlineAdminMixin, admin.StackedInline):
    model = Trailer
    readonly_fields = ('datetime_created', 'datetime_updated',)
    extra = 1


class ProjectAdmin(SortableAdminMixin, admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)
    filter_horizontal = (
        'additional_links', 'quotes', 'contacts', 'credits', 'awards')
    inlines = [FeatureInline, PriceInline, PlatformInline,
        ProjectLogosInline, ProjectImagesInline, TrailerInline]
    prepopulated_fields = {"slug": ("title",)}


class QuoteAdmin(SortableAdminMixin, admin.ModelAdmin):
    readonly_fields = ('datetime_created', 'datetime_updated',)


admin.site.register(AdditionalLink, AdditionalLinkAdmin)
admin.site.register(Attachment, AttachmentAdmin)
admin.site.register(Award, AwardAdmin)
admin.site.register(Company, CompanyAdmin)
admin.site.register(Contact, ContactAdmin)
admin.site.register(Credit, CreditAdmin)
admin.site.register(MonetizationPermission, MonetizationPermissionAdmin)
admin.site.register(Project, ProjectAdmin)
admin.site.register(Quote, QuoteAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-02 19:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0002_auto_20181002_1847'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='company',
            name='promoter_id',
        ),
        migrations.RemoveField(
            model_name='project',
            name='distribute_keyfile',
        ),
        migrations.RemoveField(
            model_name='project',
            name='promoter_id',
        ),
        migrations.AddField(
            model_name='project',
            name='distribute_access_hash',
            field=models.CharField(blank=True, help_text='The access hash from your Distribute() keyfile (https://dodistribute.com/access/add/THIS-HASH/)', max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='distribute_game_id',
            field=models.CharField(blank=True, help_text='The game ID from your Distribute() keyfile (https://dodistribute.com/games/presskit/THIS-ID/)', max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='distribute_key',
            field=models.CharField(blank=True, help_text='The key from your Distribute() keyfile filename (ds_THIS-KEY)', max_length=80, null=True),
        ),
    ]



SECRET_KEY = 'fake-key'
INSTALLED_APPS = [
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sites",
    "django.contrib.messages",
    "tests",
    "django_presskit",
    "easy_thumbnails",
    "filer",
    "adminsortable2",
    "django.contrib.admin",
]

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
    }
}

ROOT_URLCONF = "tests.urls"

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.request',
                'django.contrib.messages.context_processors.messages',
            ]
        },
    },
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from builtins import object
from django.db import models
from filer.fields.file import FilerFileField
from filer.fields.image import FilerImageField


class AdditionalLink(models.Model):
    title = models.CharField(max_length=200)
    slug = models.SlugField(unique=True)
    description = models.TextField(null=True, blank=True)
    website = models.URLField()
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.title + ' ' + self.website

class Attachment(models.Model):
    content = FilerImageField(on_delete=models.CASCADE)

    def __str__(self):
        return self.content.url

class Award(models.Model):
    description = models.CharField(max_length=200)
    info = models.CharField(max_length=1000, null=True, blank=True)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.description


class Company(models.Model):
    title = models.CharField(max_length=200)
    slug = models.SlugField(unique=True)
    website = models.URLField(null=True, blank=True)
    header_image = FilerImageField(null=True, blank=True,
                                   related_name='company_header_image',
                                   on_delete=models.SET_NULL)
    based_in = models.CharField(max_length=400, null=True, blank=True)
    description = models.TextField(null=True, blank=True)
    history = models.TextField(null=True, blank=True)
    analytics = models.CharField(max_length=200, null=True, blank=True,
                                 help_text='Your Google Analytics ID')
    founding_date = models.CharField(max_length=200, null=True,
                                     blank=True)
    press_contact = models.EmailField(
        max_length=200, null=True, blank=True,
        help_text='The primary press contact email for your company')
    phone = models.CharField(max_length=50, null=True, blank=True)
    address = models.TextField(null=True, blank=True)
    additional_links = models.ManyToManyField(AdditionalLink,
                                              blank=True)
    images = models.ManyToManyField(Attachment,
                                    through='CompanyImageAttachment',
                                    related_name='company_images')
    logos = models.ManyToManyField(Attachment,
                                   through='CompanyLogoAttachment',
                                   related_name='company_logos')
    quotes = models.ManyToManyField('Quote', blank=True)
    awards = models.ManyToManyField('Award', blank=True)
    credits = models.ManyToManyField('Credit', blank=True)
    contacts = models.ManyToManyField('Contact', blank=True)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    asset_archive = FilerFileField(blank=True, null=True,
                                   on_delete=models.SET_NULL)

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        from django.urls import reverse
        return reverse('django_presskit:company', kwargs={'company_slug': self.slug})

    class Meta(object):
        verbose_name_plural = 'companies'


class CompanyImageAttachment(models.Model):
    company = models.ForeignKey(Company, on_delete=models.CASCADE)
    attachment = models.ForeignKey(Attachment,
                                   on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']


class CompanyLogoAttachment(models.Model):
    company = models.ForeignKey(Company, on_delete=models.CASCADE)
    attachment = models.ForeignKey(Attachment,
                                   on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']


class CompanyVideo(models.Model):
    name = models.CharField(max_length=400)
    company = models.ForeignKey(Company, related_name='videos', on_delete=models.CASCADE)
    embed_url = models.URLField(null=True, blank=True)
    file = FilerFileField(null=True, blank=True,
                          related_name='company_video',
                          on_delete=models.SET_NULL)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']


class Contact(models.Model):
    name = models.CharField(max_length=300)
    website = models.URLField(null=True, blank=True)
    email = models.EmailField(null=True, blank=True)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.name


class Credit(models.Model):
    person = models.CharField(max_length=300)
    website = models.URLField(null=True, blank=True)
    role = models.TextField(null=True, blank=True)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.person + ', ' + self.role


class Feature(models.Model):
    description = models.CharField(max_length=1000)
    project = models.ForeignKey('Project', on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.description


class MonetizationPermission(models.Model):
    option = models.CharField(max_length=200)
    description = models.CharField(max_length=500)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)

    def __str__(self):
        return self.option


class Platform(models.Model):
    name = models.CharField(max_length=200)
    website = models.URLField(null=True, blank=True)
    project = models.ForeignKey('Project', on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.project.title + ' - ' + self.name


class Price(models.Model):
    price = models.CharField(max_length=200)
    project = models.ForeignKey('Project', on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.project.title + ' - ' + self.price


class Project(models.Model):
    title = models.CharField(max_length=200)
    slug = models.SlugField(unique=True)
    header_image = FilerImageField(null=True, blank=True,
                                   related_name='project_header_image',
                                   on_delete=models.SET_NULL)
    release_date = models.CharField(max_length=200)
    website = models.URLField()
    description = models.TextField()
    history = models.TextField()
    images = models.ManyToManyField(Attachment,
                                    through='ProjectImageAttachment',
                                    related_name='project_images')
    logos = models.ManyToManyField(Attachment,
                                   through='ProjectLogoAttachment',
                                   related_name='project_logos')
    press_can_request_copy = models.BooleanField()
    monetization_permission = models.ForeignKey(MonetizationPermission,
        on_delete=models.CASCADE)
    distribute_game_id = models.CharField(
        null=True, blank=True, max_length=25, help_text='The game ID from your Distribute() keyfile (https://dodistribute.com/games/presskit/THIS-ID/)')
    distribute_access_hash = models.CharField(
        null=True, blank=True, max_length=25, help_text='The access hash from your Distribute() keyfile (https://dodistribute.com/access/add/THIS-HASH/)')
    distribute_key = models.CharField(
        null=True, blank=True, max_length=80, help_text='The key from your Distribute() keyfile filename (ds_THIS-KEY)')
    quotes = models.ManyToManyField('Quote', blank=True)
    additional_links = models.ManyToManyField(AdditionalLink,
                                              blank=True)
    awards = models.ManyToManyField('Award', blank=True)
    credits = models.ManyToManyField(Credit, blank=True)
    contacts = models.ManyToManyField(Contact, blank=True)
    company = models.ForeignKey(Company, on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    asset_archive = FilerFileField(blank=True, null=True,
                                   on_delete=models.SET_NULL)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def get_absolute_url(self):
        from django.urls import reverse
        return reverse('django_presskit:project', kwargs={'project_slug': self.slug})

    def __str__(self):
        return self.title


class ProjectImageAttachment(models.Model):
    project = models.ForeignKey(Project, on_delete=models.CASCADE)
    attachment = models.ForeignKey(Attachment,
                                   on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']


class ProjectLogoAttachment(models.Model):
    project = models.ForeignKey(Project, on_delete=models.CASCADE)
    attachment = models.ForeignKey(Attachment,
                                   on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']


class Quote(models.Model):
    reviewer = models.CharField(max_length=400)
    website = models.URLField()
    publication_name = models.CharField(max_length=400)
    description = models.TextField()
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.reviewer + ', ' + self.website + ', ' + self.description


class Social(models.Model):
    name = models.CharField(max_length=200)
    website = models.URLField()
    company = models.ForeignKey(Company, on_delete=models.CASCADE)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']

    def __str__(self):
        return self.company.title + ' ' + self.name


class Trailer(models.Model):
    name = models.CharField(max_length=400)
    embed_url = models.URLField(null=True, blank=True)
    project = models.ForeignKey(Project, related_name='videos',
                                on_delete=models.CASCADE)
    file = FilerFileField(null=True, blank=True,
                          related_name='trailer_video',
                          on_delete=models.SET_NULL)
    datetime_created = models.DateTimeField(auto_now_add=True)
    datetime_updated = models.DateTimeField(auto_now=True)
    my_order = models.PositiveIntegerField(default=0, blank=False, null=False)

    class Meta(object):
        ordering = ['my_order', 'datetime_updated']



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import zipfile
import os
from io import BytesIO

from django.conf import settings
from django.http import HttpResponse, Http404
from django.shortcuts import render, redirect
from django.views.decorators.cache import cache_page

from .models import Company, Project

def fallback(func):
  def decorator(*args, **kwargs):
    try:
      return func(*args, **kwargs)
    except (Company.DoesNotExist, Project.DoesNotExist) as e:
      return redirect('django_presskit:default')

  return decorator

@fallback
def presskit(request, company_slug=None):
    if not company_slug:
      try:
        company = Company.objects.get(pk=settings.DJANGO_PRESSKIT_DEFAULT_COMPANY_ID)
      except Exception as e:
        return render(request, 'django_presskit/no_default.html')
    else:
      company = Company.objects.get(slug=company_slug)
    context = {
      'request': request,
      'company': company,
    }
    return render(request, 'django_presskit/company.html', context)

@fallback
def project(request, project_slug):
    project = Project.objects.get(slug=project_slug)
    context = {
      'request': request,
      'project': project,
    }
    return render(request, 'django_presskit/project.html', context)

def project_xml(request, project_slug):
    project = Project.objects.get(slug=project_slug)
    context = {
      'project': project,
    }
    return render(request, 'django_presskit/data.xml', context, content_type='text/xml')

def project_header(request, project_slug):
    project = Project.objects.get(slug=project_slug)
    if project.header_image:
      return redirect(project.header_image.url, permanent=True)
    else:
      raise Http404("No header image for this project.")



# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-02 18:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.file
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filer', '0010_auto_20180414_2058'),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AdditionalLink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(unique=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('website', models.URLField()),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Attachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', filer.fields.image.FilerImageField(on_delete=django.db.models.deletion.CASCADE, to=settings.FILER_IMAGE_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Award',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=200)),
                ('info', models.CharField(blank=True, max_length=1000, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Company',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(unique=True)),
                ('website', models.URLField(blank=True, null=True)),
                ('based_in', models.CharField(blank=True, max_length=400, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('history', models.TextField(blank=True, null=True)),
                ('analytics', models.CharField(blank=True, help_text='Your Google Analytics ID', max_length=200, null=True)),
                ('promoter_id', models.CharField(blank=True, help_text='A product ID in Promoter with quotes for your company', max_length=20, null=True)),
                ('founding_date', models.CharField(blank=True, max_length=200, null=True)),
                ('press_contact', models.EmailField(blank=True, help_text='The primary press contact email for your company', max_length=200, null=True)),
                ('phone', models.CharField(blank=True, max_length=50, null=True)),
                ('address', models.TextField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('additional_links', models.ManyToManyField(blank=True, to='django_presskit.AdditionalLink')),
                ('awards', models.ManyToManyField(blank=True, to='django_presskit.Award')),
            ],
            options={
                'verbose_name_plural': 'companies',
            },
        ),
        migrations.CreateModel(
            name='CompanyImageAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
            ],
        ),
        migrations.CreateModel(
            name='CompanyLogoAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
            ],
        ),
        migrations.CreateModel(
            name='CompanyVideo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=400)),
                ('embed_url', models.URLField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='videos', to='django_presskit.Company')),
                ('file', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='company_video', to='filer.File')),
            ],
        ),
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300)),
                ('website', models.URLField(blank=True, null=True)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Credit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('person', models.CharField(max_length=300)),
                ('website', models.URLField(blank=True, null=True)),
                ('role', models.TextField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Feature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=1000)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='MonetizationPermission',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('option', models.CharField(max_length=200)),
                ('description', models.CharField(max_length=500)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Platform',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('website', models.URLField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Price',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.CharField(max_length=200)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(unique=True)),
                ('release_date', models.CharField(max_length=200)),
                ('website', models.URLField()),
                ('description', models.TextField()),
                ('history', models.TextField()),
                ('press_can_request_copy', models.BooleanField()),
                ('promoter_id', models.CharField(blank=True, max_length=20, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('additional_links', models.ManyToManyField(blank=True, to='django_presskit.AdditionalLink')),
                ('awards', models.ManyToManyField(blank=True, to='django_presskit.Award')),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
                ('contacts', models.ManyToManyField(blank=True, to='django_presskit.Contact')),
                ('credits', models.ManyToManyField(blank=True, to='django_presskit.Credit')),
                ('distribute_keyfile', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='project_distribute_keyfile', to='filer.File')),
                ('header_image', filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='project_header_image', to=settings.FILER_IMAGE_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ProjectImageAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project')),
            ],
        ),
        migrations.CreateModel(
            name='ProjectLogoAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project')),
            ],
        ),
        migrations.CreateModel(
            name='Quote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reviewer', models.CharField(max_length=400)),
                ('website', models.URLField()),
                ('publication_name', models.CharField(max_length=400)),
                ('description', models.TextField()),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Social',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('website', models.URLField()),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
            ],
        ),
        migrations.CreateModel(
            name='Trailer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=400)),
                ('embed_url', models.URLField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('file', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='trailer_video', to='filer.File')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='videos', to='django_presskit.Project')),
            ],
        ),
        migrations.AddField(
            model_name='project',
            name='images',
            field=models.ManyToManyField(related_name='project_images', through='django_presskit.ProjectImageAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='project',
            name='logos',
            field=models.ManyToManyField(related_name='project_logos', through='django_presskit.ProjectLogoAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='project',
            name='monetization_permission',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.MonetizationPermission'),
        ),
        migrations.AddField(
            model_name='project',
            name='quotes',
            field=models.ManyToManyField(blank=True, to='django_presskit.Quote'),
        ),
        migrations.AddField(
            model_name='price',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project'),
        ),
        migrations.AddField(
            model_name='platform',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project'),
        ),
        migrations.AddField(
            model_name='feature',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project'),
        ),
        migrations.AddField(
            model_name='company',
            name='contacts',
            field=models.ManyToManyField(blank=True, to='django_presskit.Contact'),
        ),
        migrations.AddField(
            model_name='company',
            name='credits',
            field=models.ManyToManyField(blank=True, to='django_presskit.Credit'),
        ),
        migrations.AddField(
            model_name='company',
            name='header_image',
            field=filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='company_header_image', to=settings.FILER_IMAGE_MODEL),
        ),
        migrations.AddField(
            model_name='company',
            name='images',
            field=models.ManyToManyField(related_name='company_images', through='django_presskit.CompanyImageAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='company',
            name='logos',
            field=models.ManyToManyField(related_name='company_logos', through='django_presskit.CompanyLogoAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='company',
            name='quotes',
            field=models.ManyToManyField(blank=True, to='django_presskit.Quote'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.test import TestCase, Client
from django.urls import reverse

from django_presskit.templatetags import dpk_util
from django_presskit.models import Company, Project,\
    MonetizationPermission


class MarkdownFilterTests(TestCase):

    def test_filter(self):
        text = '_hello_ & &amp; <span>hi</span> congratulations'
        expected = '<p><em>hello</em> &amp; &amp; <span>hi</span> congratulations</p>'
        self.assertEqual(dpk_util.markdown_filter(text), expected)


class ProtocolFilterTests(TestCase):

    def test_filter_with_empty_string(self):
        text = ''
        expected = ''
        self.assertEqual(dpk_util.with_protocol(text), expected)

    def test_filter_with_protocol(self):
        text = 'https://test.com'
        expected = 'https://test.com'
        self.assertEqual(dpk_util.with_protocol(text), expected)

    def test_filter_without_protocol(self):
        text = 'test.com'
        expected = '//test.com'
        self.assertEqual(dpk_util.with_protocol(text), expected)


class DomainFilterTests(TestCase):

    def test_filter_with_empty_string(self):
        text = ''
        expected = ''
        self.assertEqual(dpk_util.domain(text), expected)

    def test_filter_with_protocol(self):
        text = 'https://test.com'
        expected = 'test.com'
        self.assertEqual(dpk_util.domain(text), expected)

    def test_filter_without_protocol(self):
        text = 'test.com'
        expected = 'test.com'
        self.assertEqual(dpk_util.domain(text), expected)


class AbsoluteUrlTagTests(TestCase):

    def setUp(self):
        comp = Company.objects.create(title='Test Company',
            slug='test-company',
            description='Description',
            address='Place')
        perms = MonetizationPermission.objects.create(option='Test Permission')
        self.project = Project.objects.create(title='Test Project',
            slug='test-project',
            press_can_request_copy=True,
            company=comp,
            monetization_permission=perms)

    def test_tag(self):
        c = Client()
        response = c.get(reverse('django_presskit:company', kwargs={'company_slug': 'test-company'}))
        expected = '"@id": "http://testserver/projects/test-project/"'
        self.assertContains(response, expected)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django_presskit",
    version="1.3.1",
    author="Future Proof Games",
    author_email="info@futureproofgames.com",
    description="A port of presskit() to Django",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/FutureProofGames/django-presskit.git",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.1",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
)



from django.conf.urls import url

from . import views

app_name = 'presskit'
urlpatterns = [
    url(r'^$', views.presskit, name='default'),
    url(r'^(?P<company_slug>[-\w]+)/$', views.presskit, name='company'),
    url(r'^projects/(?P<project_slug>[-\w]+)/$', views.project, name='project'),
    url(r'^projects/(?P<project_slug>[-\w]+)/data.xml$', views.project_xml, name='project_xml'),
    url(r'^projects/(?P<project_slug>[-\w]+)/images/header.png$', views.project_header, name='project_header'),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2019-04-02 11:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0004_auto_20190202_2017'),
        ('django_presskit', '0004_auto_20190123_0157'),
    ]

    operations = [
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from builtins import str
from django.test import TestCase

from django_presskit.models import Company, Project, AdditionalLink,\
    Award, Contact, Credit, Feature, MonetizationPermission, Platform,\
    Price, Quote, Social


class AdditionalLinkModelTests(TestCase):

    def test_unicode(self):
        link = AdditionalLink(title='Test Link', website='https://test.com')
        self.assertEqual(str(link), 'Test Link https://test.com')


class AwardModelTests(TestCase):

    def test_unicode(self):
        award = Award(description='Test Award')
        self.assertEqual(str(award), 'Test Award')


class CompanyModelTests(TestCase):

    def test_company_url(self):
        comp = Company(title='Test Company', slug='test-company')
        self.assertEqual(comp.get_absolute_url(), '/test-company/')

    def test_unicode(self):
        comp = Company(title='Test Company', slug='test-company')
        self.assertEqual(str(comp), 'Test Company')


class ContactModelTests(TestCase):

    def test_unicode(self):
        contact = Contact(name='Test Contact')
        self.assertEqual(str(contact), 'Test Contact')


class CreditModelTests(TestCase):

    def test_unicode(self):
        credit = Credit(person='Test Person', role='Test Role')
        self.assertEqual(str(credit), 'Test Person, Test Role')


class FeatureModelTests(TestCase):

    def test_unicode(self):
        feature = Feature(description='Test Feature')
        self.assertEqual(str(feature), 'Test Feature')


class MonetizationPermissionModelTests(TestCase):

    def test_unicode(self):
        perms = MonetizationPermission(option='Test Permission')
        self.assertEqual(str(perms), 'Test Permission')


class PlatformModelTests(TestCase):

    def test_unicode(self):
        project = Project(title='Test Project')
        plat = Platform(project=project, name='Test Platform')
        self.assertEqual(str(plat), 'Test Project - Test Platform')


class PriceModelTests(TestCase):

    def test_unicode(self):
        project = Project(title='Test Project')
        price = Price(project=project, price='Test Price')
        self.assertEqual(str(price), 'Test Project - Test Price')


class ProjectModelTests(TestCase):

    def test_project_url(self):
        comp = Company(title='Test Company', slug='test-company')
        proj = Project(title='Test Project', slug='test-project', company=comp)
        self.assertEqual(proj.get_absolute_url(), '/projects/test-project/')

    def test_unicode(self):
        proj = Project(title='Test Project')
        self.assertEqual(str(proj), 'Test Project')


class QuoteModelTests(TestCase):

    def test_unicode(self):
        quote = Quote(reviewer='Test Person', description='Test Description',
                      website='https://test.com')
        self.assertEqual(str(quote), 'Test Person, https://test.com, Test Description')


class SocialModelTests(TestCase):

    def test_unicode(self):
        comp = Company(title='Test Company', slug='test-company')
        social = Social(company=comp, name='Test Social')
        self.assertEqual(str(social), 'Test Company Test Social')
